diff --git a/FileIO/Legacy/MeshIO.cpp b/FileIO/Legacy/MeshIO.cpp
index 9353705b1363f25fee521b6f70f4d0780ca8a9d1..cb0b5449f62f71fc6707623362e78b707c5a6bb6 100644
--- a/FileIO/Legacy/MeshIO.cpp
+++ b/FileIO/Legacy/MeshIO.cpp
@@ -168,7 +168,7 @@ MeshLib::Element* MeshIO::readElement(const std::string& line,
 
 	switch(elem_type)
 	{
-	case MeshElemType::EDGE: {
+	case MeshElemType::LINE: {
 		for (int i = 0; i < 2; ++i)
 			ss >> idx[i];
 		// edge_nodes array will be deleted from Edge object
@@ -286,7 +286,7 @@ void MeshIO::writeElementsExceptLines(std::vector<MeshLib::Element*> const& ele_
 	size_t n_elements(0);
 
 	for (size_t i(0); i < ele_vector_size; ++i) {
-		if ((ele_vec[i])->getGeomType() == MeshElemType::EDGE) {
+		if ((ele_vec[i])->getGeomType() == MeshElemType::LINE) {
 			non_line_element[i] = false;
 			non_null_element[i] = false;
 		} else {
diff --git a/FileIO/RapidXmlIO/BoostVtuInterface.cpp b/FileIO/RapidXmlIO/BoostVtuInterface.cpp
index 8fae54eeb2243d37b856cd91cfd4577d2f27ca77..5462a3bc4354b5f9306dc3d7ddbc99a78924c693 100644
--- a/FileIO/RapidXmlIO/BoostVtuInterface.cpp
+++ b/FileIO/RapidXmlIO/BoostVtuInterface.cpp
@@ -500,7 +500,7 @@ unsigned BoostVtuInterface::getVTKElementID(MeshElemType type) const
 {
 	switch (type)
 	{
-	case MeshElemType::EDGE:
+	case MeshElemType::LINE:
 		return 3;
 	case MeshElemType::TRIANGLE:
 		return 5;
diff --git a/FileIO/RapidXmlIO/RapidVtuInterface.cpp b/FileIO/RapidXmlIO/RapidVtuInterface.cpp
index 86008571299b93142bc9d17fd59f472679417dc7..76ce86a8f011484a96049ec9816e817eff4cb94f 100644
--- a/FileIO/RapidXmlIO/RapidVtuInterface.cpp
+++ b/FileIO/RapidXmlIO/RapidVtuInterface.cpp
@@ -431,7 +431,7 @@ unsigned RapidVtuInterface::getVTKElementID(MeshElemType type) const
 {
 	switch (type)
 	{
-	case MeshElemType::EDGE:
+	case MeshElemType::LINE:
 		return 3;
 	case MeshElemType::TRIANGLE:
 		return 5;
diff --git a/Gui/VtkVis/VtkMeshSource.cpp b/Gui/VtkVis/VtkMeshSource.cpp
index 1904711601036a34d84bf1eed1c30a37f20c9e0a..555b4a76b5b840ab68e78bdefcb36d262cda40e5 100644
--- a/Gui/VtkVis/VtkMeshSource.cpp
+++ b/Gui/VtkVis/VtkMeshSource.cpp
@@ -140,7 +140,7 @@ int VtkMeshSource::RequestData( vtkInformation* request,
 
 		switch (elem->getGeomType())
 		{
-		case MeshElemType::EDGE:
+		case MeshElemType::LINE:
 			type = 3;
 			break;
 		case MeshElemType::TRIANGLE:
diff --git a/MeshLib/Elements/Edge.h b/MeshLib/Elements/Edge.h
index 6fac5eda898149a8aa252fee6b130ff8f59040cf..152f2bc114f43395f7bb2a322184071a18e1e5ee 100644
--- a/MeshLib/Elements/Edge.h
+++ b/MeshLib/Elements/Edge.h
@@ -19,7 +19,7 @@
 
 namespace MeshLib {
 
-typedef TemplateEdge<2,CellType::EDGE2> Edge;
+typedef TemplateEdge<2,CellType::LINE2> Edge;
 
 }
 
diff --git a/MeshLib/Mesh.cpp b/MeshLib/Mesh.cpp
index 8c64d5b74e95429eb5be46074dcabd4bc17d044b..26311c957e30136e1f546758d9dc41e05b7e813a 100644
--- a/MeshLib/Mesh.cpp
+++ b/MeshLib/Mesh.cpp
@@ -101,7 +101,7 @@ void Mesh::makeNodesUnique()
 	//set correct id for each node
 
 	//if (this->getDimension() > 1)
-	//	this->removeMeshElements(MeshElemType::EDGE);
+	//	this->removeMeshElements(MeshElemType::LINE);
 
 }
 
@@ -179,7 +179,7 @@ void Mesh::setElementsConnectedToElements()
 		// create vector with all elements connected to current element (includes lots of doubles!)
 		std::vector<Element*> neighbors;
 		Element *const element (_elements[m]);
-		if (element->getGeomType() != MeshElemType::EDGE)
+		if (element->getGeomType() != MeshElemType::LINE)
 		{
 			const size_t nNodes (element->getNNodes());
 			for (unsigned n(0); n<nNodes; ++n)
@@ -192,7 +192,7 @@ void Mesh::setElementsConnectedToElements()
 
 			for (unsigned i(0); i<nNeighbors; ++i)
 			{
-				if (element->addNeighbor(neighbors[i]) && neighbors[i]->getGeomType() != MeshElemType::EDGE)
+				if (element->addNeighbor(neighbors[i]) && neighbors[i]->getGeomType() != MeshElemType::LINE)
 				{
 					neighbors[i]->addNeighbor(element);
 				}
diff --git a/MeshLib/MeshEnums.cpp b/MeshLib/MeshEnums.cpp
index c504eaa56caf89d3593bc14e39a88ce15d25bd8a..d0cb803a3ee702ca024f1f69fa07fe54548b6d13 100644
--- a/MeshLib/MeshEnums.cpp
+++ b/MeshLib/MeshEnums.cpp
@@ -16,7 +16,7 @@
 
 const std::string MeshElemType2String(const MeshElemType t)
 {
-	if (t == MeshElemType::EDGE)
+	if (t == MeshElemType::LINE)
 		return "line";
 	if (t == MeshElemType::QUAD)
 		return "quad";
@@ -36,7 +36,7 @@ const std::string MeshElemType2String(const MeshElemType t)
 MeshElemType String2MeshElemType(const std::string &s)
 {
 	if (s.compare("line") == 0)
-		return MeshElemType::EDGE;
+		return MeshElemType::LINE;
 	if (s.compare("quad") == 0)
 		return MeshElemType::QUAD;
 	if (s.compare("hex")  == 0)
diff --git a/MeshLib/MeshEnums.h b/MeshLib/MeshEnums.h
index d8d13ab2480515ff006f61a9cb4f098aeed529fd..69950507a6a29eeb48693098624a2f81ef0ea2e9 100644
--- a/MeshLib/MeshEnums.h
+++ b/MeshLib/MeshEnums.h
@@ -23,7 +23,7 @@
 enum class MeshElemType
 {
 	INVALID,
-	EDGE,
+	LINE,
 	QUAD,
 	HEXAHEDRON,
 	TRIANGLE,
@@ -38,8 +38,8 @@ enum class MeshElemType
 enum class CellType
 {
 	INVALID,
-	EDGE2,
-	EDGE3,
+	LINE2,
+	LINE3,
 	TRI3,
 	TRI6,
 	QUAD4,
diff --git a/MeshLib/MeshQuality/MeshQualityEquiAngleSkew.cpp b/MeshLib/MeshQuality/MeshQualityEquiAngleSkew.cpp
index b4e651663203b03b8cd97092cb1b7d7635c6dc41..0d0861f20613331eaab824a3a6cfbf9c30604965 100644
--- a/MeshLib/MeshQuality/MeshQualityEquiAngleSkew.cpp
+++ b/MeshLib/MeshQuality/MeshQualityEquiAngleSkew.cpp
@@ -47,7 +47,7 @@ void MeshQualityEquiAngleSkew::check ()
 		const Element* elem (elements[k]);
 		switch (elem->getGeomType())
 		{
-		case MeshElemType::EDGE:
+		case MeshElemType::LINE:
 			_mesh_quality_measure[k] = -1.0;
 			break;
 		case MeshElemType::TRIANGLE:
diff --git a/MeshLib/MeshQuality/MeshQualityShortestLongestRatio.cpp b/MeshLib/MeshQuality/MeshQualityShortestLongestRatio.cpp
index 32c2b0412733e5072593428a65a0a94ccf6e62ea..dbcfac3c4871622f711a9a1f1267daeea2e466e7 100644
--- a/MeshLib/MeshQuality/MeshQualityShortestLongestRatio.cpp
+++ b/MeshLib/MeshQuality/MeshQualityShortestLongestRatio.cpp
@@ -34,7 +34,7 @@ void MeshQualityShortestLongestRatio::check()
 		const Element* elem (elements[k]);
 		switch (elem->getGeomType())
 		{
-		case MeshElemType::EDGE:
+		case MeshElemType::LINE:
 			_mesh_quality_measure[k] = 1.0;
 			break;
 		case MeshElemType::TRIANGLE: {
diff --git a/MeshLib/MeshQuality/MeshQualityVolume.cpp b/MeshLib/MeshQuality/MeshQualityVolume.cpp
index 6fd05ea2953685c0e7197684a454d15d5b5d5aff..9c6066944acd81e075851f17f602f5d04f93f918 100644
--- a/MeshLib/MeshQuality/MeshQualityVolume.cpp
+++ b/MeshLib/MeshQuality/MeshQualityVolume.cpp
@@ -36,7 +36,7 @@ void MeshQualityVolume::check()
 	{
 		const Element* elem (elements[k]);
 		MeshElemType elem_type (elem->getGeomType());
-		if (elem_type == MeshElemType::EDGE
+		if (elem_type == MeshElemType::LINE
 		    || elem_type == MeshElemType::TRIANGLE
 		    || elem_type == MeshElemType::QUAD)
 		{
diff --git a/MeshLib/Elements/TemplateEdge.h b/MeshLib/Elements/TemplateEdge.h
index b48095243fa98bdc66f1c9527874a94473902fb5..45e2fe5a239cafef4a69304771f9c7d384bdc06e 100644
--- a/MeshLib/Elements/TemplateEdge.h
+++ b/MeshLib/Elements/TemplateEdge.h
@@ -86,10 +86,10 @@ public:
 	}
 
 	/**
 	 * Method returns the type of the element. In this case EDGE will be returned.
 	 * @return MeshElemType::EDGE
 	 */
-	virtual MeshElemType getGeomType() const { return MeshElemType::EDGE; }
+	virtual MeshElemType getGeomType() const { return MeshElemType::LINE; }
 
 	/**
 	 * Get the type of the element in context of the finite element method.
@@ -86,10 +86,10 @@ public:
 
 	/**
-	 * Method returns the type of the element. In this case EDGE will be returned.
-	 * @return MeshElemType::EDGE
+	 * Method returns the type of the element. In this case LINE will be returned.
+	 * @return MeshElemType::LINE
 	 */